@@ -197,16 +197,20 @@ class Client:
         identifiers=None,
         upload_location_replace_map=None,
         mediafile_object=None,
+        user_email=None,
     ):
         if not identifiers:
             identifiers = list()
         if not upload_location_replace_map:
             upload_location_replace_map = dict()
         upload_location = self.__get_upload_location(
-            entity_id, filename, True, identifiers, mediafile_object
+            entity_id, filename, False, identifiers, mediafile_object
         )
         for current_location, new_location in upload_location_replace_map.items():
             upload_location = upload_location.replace(current_location, new_location)
+        upload_location = upload_location.replace('"', "")
+        if user_email and "&user_email" not in upload_location:
+            upload_location = f"{upload_location}&user_email={user_email}"
         print(upload_location)
         mediafile = requests.get(file_url, proxies=self.proxies).content
         response = requests.post(
