@@ -210,10 +210,14 @@ class CSVMultiObject(CSVParser):
 
     def is_datetime(self, value):
         try:
-            parser.parse(value)
-            return True
-        except (ValueError, TypeError):
+            int(value)
             return False
+        except (ValueError, TypeError):
+            try:
+                parser.parse(value)
+                return True
+            except (ValueError, TypeError):
+                return False
 
     def parse_datetime(self, value):
         return parser.parse(value)
@@ -270,6 +274,14 @@ class CSVMultiObject(CSVParser):
                 for key, value in row.items():
                     if not value:
                         continue
+                    if not key or isinstance(value, list):
+                        if len(value) == 1 and value[0] == '':
+                            continue
+                        if "invalid_value" not in self.get_errors():
+                            self.set_error("invalid_value", list())
+                        message = f'{get_error_code(ErrorCode.INVALID_VALUE, get_write())} | value:{value} | line_number:{row_number} - The value "{value}" is invalid, most likely caused by exceeding allowed columns.'
+                        self.get_errors()["invalid_value"].append(message)
+                    original_value = value
                     if key != identifying_column:
                         value = value.lower()
                     if key == "file_source":
@@ -301,7 +313,7 @@ class CSVMultiObject(CSVParser):
                     elif key in self.top_level_fields and self.__field_allowed(
                         type, key, value
                     ):
-                        indexed_dict[type][id][key] = value
+                        indexed_dict[type][id][key] = original_value
                     elif (
                         key not in self.index_mapping.values()
                         or self.include_indexed_field
@@ -312,7 +324,7 @@ class CSVMultiObject(CSVParser):
                             indexed_dict[type][id].setdefault("metadata", list())
                             options = metadata_info.get("value_options")
                             if self.is_datetime(value):
-                                value = self.parse_datetime(value)
+                                original_value = self.parse_datetime(value)
                             if options and value not in options:
                                 if "invalid_value" not in self.get_errors():
                                     self.set_error("invalid_value", list())
@@ -320,7 +332,9 @@ class CSVMultiObject(CSVParser):
                                 self.get_errors()["invalid_value"].append(message)
 
                             indexed_dict[type][id]["metadata"].append(
-                                self._get_metadata_object(metadata_key, value, lang)
+                                self._get_metadata_object(
+                                    metadata_key, original_value, lang
+                                )
                             )
         self.__validate_indexed_dict(indexed_dict)
         self.__add_required_fields(indexed_dict)
