@@ -103,6 +103,18 @@ class BaseObjectConfiguration(ABC):
                 )
                 if sanitized_value:
                     sanitized_document[key] = sanitized_value
+            elif isinstance(value, list):
+                sanitized_document[key] = [
+                    element.strip() if isinstance(element, str) else element
+                    for element in value
+                    if element
+                ]
+                if all(isinstance(element, str) for element in sanitized_document[key]):
+                    sanitized_document[key] = list(set(sanitized_document[key]))
+            elif isinstance(value, str):
+                lines = value.splitlines()
+                value = "\n".join(line.strip() for line in lines).strip()
+                sanitized_document[key] = value.strip()
             elif value:
                 sanitized_document[key] = value
         return sanitized_document
